<?php
/**
 * Plugin Name: GR - Splash Cursor
 * Description: Adds a WebGL fluid cursor animation to your site.
 * Version: 1.1
 * Author: Grega Rednak
 */

// Freemius SDK bootstrap
if ( ! function_exists( 'sc_fs' ) ) {
    // Create a helper function for easy SDK access.
    function sc_fs() {
        global $sc_fs;

        if ( ! isset( $sc_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/vendor/freemius/start.php';
            $sc_fs = fs_dynamic_init( array(
                'id'                  => '19360',
                'slug'                => 'splash-cursor',
                'type'                => 'plugin',
                'public_key'          => 'pk_8cb90ab245bbba7216e2b44a0940f',
                'is_premium'          => true,
                'is_premium_only'     => true,
                'has_addons'          => false,
                'has_paid_plans'      => true,
                'is_org_compliant'    => false,
                'trial'               => array(
                    'days'               => 3,
                    'is_require_payment' => false,
                ),
                'menu'                => array(
                    'slug'           => 'splash-cursor',
                    'support'        => false,
                    'parent'         => array(
                        'slug' => 'options-general.php',
                    ),
                ),
            ) );
        }

        return $sc_fs;
    }

    // Init Freemius.
    sc_fs();
    // Signal that SDK was initiated.
    do_action( 'sc_fs_loaded' );
}

// Defer plugin logic until Freemius has loaded
add_action('plugins_loaded', function () {

    // Enqueue frontend JS + settings injection
    add_action('wp_enqueue_scripts', function () {
        if (is_admin()) return;
		if ( ! sc_fs()->can_use_premium_code() ) {
			return;
		}

        $load_on_mobile = get_option('splash_cursor_load_mobile', false);
        if (wp_is_mobile() && !$load_on_mobile) return;

        wp_enqueue_script(
            'splash-cursor-script',
            plugins_url('splash-cursor.js', __FILE__),
            array(),
            '1.0',
            true
        );

        $options = array(
            'SIM_RESOLUTION' => (int) get_option('splash_cursor_sim_resolution') ?: 128,
            'DYE_RESOLUTION' => (int) get_option('splash_cursor_dye_resolution') ?: 1440,
            'CAPTURE_RESOLUTION' => (int) get_option('splash_cursor_capture_resolution') ?: 512,
            'DENSITY_DISSIPATION' => (float) get_option('splash_cursor_density_dissipation') ?: 3.5,
            'VELOCITY_DISSIPATION' => (float) get_option('splash_cursor_velocity_dissipation') ?: 2,
            'PRESSURE' => (float) get_option('splash_cursor_pressure') ?: 0.1,
            'PRESSURE_ITERATIONS' => (int) get_option('splash_cursor_pressure_iterations') ?: 20,
            'CURL' => (float) get_option('splash_cursor_curl') ?: 3,
            'SPLAT_RADIUS' => (float) get_option('splash_cursor_splat_radius') ?: 0.2,
            'SPLAT_FORCE' => (float) get_option('splash_cursor_splat_force') ?: 6000,
            'SHADING' => (bool) get_option('splash_cursor_shading', true),
            'COLOR_UPDATE_SPEED' => (float) get_option('splash_cursor_color_speed') ?: 10,
            'TRANSPARENT' => true,
            'BACK_COLOR' => array('r' => 0.5, 'g' => 0, 'b' => 0),
        );

        wp_localize_script('splash-cursor-script', 'SPLASH_CURSOR_OPTIONS', $options);
    });

    // Admin menu
    add_action('admin_menu', function () {
        add_options_page(
            'Splash Cursor Settings',
            'Splash Cursor',
            'manage_options',
            'splash-cursor',
            'splash_cursor_settings_page'
        );
    });

    // Add plugin settings link
    add_filter('plugin_action_links_' . plugin_basename(__FILE__), function ($links) {
        $settings_link = '<a href="options-general.php?page=splash-cursor">Settings</a>';
        array_unshift($links, $settings_link);
        return $links;
    });

    // Admin settings registration
    add_action('admin_init', function () {
        $fields = [
            'splash_cursor_load_mobile',
            'splash_cursor_sim_resolution',
            'splash_cursor_dye_resolution',
            'splash_cursor_capture_resolution',
            'splash_cursor_density_dissipation',
            'splash_cursor_velocity_dissipation',
            'splash_cursor_pressure',
            'splash_cursor_pressure_iterations',
            'splash_cursor_curl',
            'splash_cursor_splat_radius',
            'splash_cursor_splat_force',
            'splash_cursor_shading',
            'splash_cursor_color_speed'
        ];

        foreach ($fields as $f) {
            register_setting('splash_cursor', $f);
        }

        add_settings_section('splash_cursor_section_main', 'Main Settings', null, 'splash_cursor');

        function add_splash_field($id, $label, $type = 'number', $step = '1', $placeholder = '') {
            add_settings_field(
                $id,
                $label,
                function () use ($id, $type, $step, $placeholder) {
                    $val = get_option($id, '');
                    if ($type === 'checkbox') {
                        echo "<input type='checkbox' name='$id' value='1' " . checked(1, $val, false) . " />";
                    } else {
                        $ph = $placeholder ? "placeholder='$placeholder'" : "";
                        echo "<input type='$type' name='$id' value='" . esc_attr($val) . "' step='$step' $ph />";
                    }
                },
                'splash_cursor',
                'splash_cursor_section_main'
            );
        }

        add_splash_field('splash_cursor_load_mobile', 'Load on Mobile Devices', 'checkbox');
        add_splash_field('splash_cursor_sim_resolution', 'SIM Resolution', 'number', '1', '128');
        add_splash_field('splash_cursor_dye_resolution', 'DYE Resolution', 'number', '1', '1440');
        add_splash_field('splash_cursor_capture_resolution', 'CAPTURE Resolution', 'number', '1', '512');
        add_splash_field('splash_cursor_density_dissipation', 'Density Dissipation', 'number', '0.1', '3.5');
        add_splash_field('splash_cursor_velocity_dissipation', 'Velocity Dissipation', 'number', '0.1', '2');
        add_splash_field('splash_cursor_pressure', 'Pressure', 'number', '0.01', '0.1');
        add_splash_field('splash_cursor_pressure_iterations', 'Pressure Iterations', 'number', '1', '20');
        add_splash_field('splash_cursor_curl', 'Curl', 'number', '0.1', '3');
        add_splash_field('splash_cursor_splat_radius', 'Splat Radius', 'number', '0.01', '0.2');
        add_splash_field('splash_cursor_splat_force', 'Splat Force', 'number', '1', '6000');
        add_splash_field('splash_cursor_color_speed', 'Color Update Speed', 'number', '0.1', '10');
    });
});

// Settings page with license check
function splash_cursor_settings_page() {
    if ( ! sc_fs()->can_use_premium_code() ) {
        echo '<div class="notice notice-error"><p>';
        echo 'Please activate your license to access Splash Cursor settings.';
        echo '</p></div>';
        return;
    }

    ?>
    <div class="wrap">
        <h1>Splash Cursor Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('splash_cursor');
            do_settings_sections('splash_cursor');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}
